<?php

/**
 * Callback function to define the payment parameters.
 * 
 * All parameters are mandatory to fill in.
 * These parameters are:
 * i.               mid (Merchant ID)
 * ii.            terminal_num
 * iii.         url to CG web-service (cg_url)
 * iv.            username
 * v.              password
 * vi.  	Ok page (will not be used by CG as this is set on CG as well)
 * vii.	Not Ok page (will not be used by CG as this is set on CG as well)
 * viii.	Installments – Number of max installments.
 */
function cg_payment_admin_settings($form, &$form_state) {
  
  // A reffernce to the site base url variable. see: http://api.drupal.org/api/drupal/developer%21globals.php/global/base_url/7
  global $base_url;
  
  // The intro div contains the urls for the ok and not ok pages.
  $form['intro'] = array();
  $form['intro']['#markup'] = '<div id="intro">';
  $form['intro']['#markup'] .= '<div>'.t('The OK url is:').' '.$base_url.'/'.OK_PAGE.'</div>';
  $form['intro']['#markup'] .= '<div>'.t('The NOT OK url is:').' '.$base_url.'/'.NOT_OK_PAGE.'</div>';
  $form['intro']['#markup'] .= '</div>';

  // Merchant Id
  $form['mid'] = array();
  $form['mid']['#type'] = 'textfield';
  $form['mid']['#title'] = t('Merchant ID');
  $form['mid']['#required'] = true;
  $form['mid']['#default_value'] = variable_get('cg_payment_admin_settings_mid', null);

  // Terminal number
  $form['terminal_num'] = array();
  $form['terminal_num']['#type'] = 'textfield';
  $form['terminal_num']['#title'] = t('Terminal Number');
  $form['terminal_num']['#required'] = true;
  $form['terminal_num']['#default_value'] = variable_get('cg_payment_admin_settings_terminal_num', null);

  $form['cg_url'] = array();
  $form['cg_url']['#type'] = 'textfield';
  $form['cg_url']['#title'] = t('URL to CG web-service');
  $form['cg_url']['#description'] = t('The URL should begin with a scheme such as "http:"');
  $form['cg_url']['#required'] = true;
  $form['cg_url']['#default_value'] = variable_get('cg_payment_admin_settings_cg_url', null);

  $form['username'] = array();
  $form['username']['#type'] = 'textfield';
  $form['username']['#title'] = t('Username');
  $form['username']['#required'] = true;
  $form['username']['#default_value'] = variable_get('cg_payment_admin_settings_username', null);

  $form['password'] = array();
  $form['password']['#type'] = 'password';
  $form['password']['#title'] = t('Password');
  $form['password']['#required'] = true;
  $form['password']['#default_value'] = '';

  $form['installments'] = array();
  $form['installments']['#type'] = 'textfield';
  $form['installments']['#title'] = t('Installments');
  $form['installments']['#description'] = t('Number of max installments.');
  $form['installments']['#required'] = true;
  $form['installments']['#default_value'] = variable_get('cg_payment_admin_settings_installments', 1);

  $form['submit'] = array('#type' => 'submit', '#value' => t('Save configuration'));

  $form['#validate'][] = 'cg_payment_admin_settings_validate';
  $form['#submit'][] = 'cg_payment_admin_settings_submit';
  
  return $form;
}

/**
 * Form validation handler for cg_payment_admin_settings().
 *
 * @see cg_payment_admin_settings()
 */
function cg_payment_admin_settings_validate($form, &$form_state) {

  // Validation to the mid value
  if (!is_numeric($form_state['values']['mid'])) {
    form_set_error('error', t('The mid value is not numeric'));
  }

  // Validation to the terminal_num value
  if (!preg_match('/^[A-Za-z0-9]+$/', $form_state['values']['terminal_num'])) {
    form_set_error('error', t('The terminal_num value is not AlphaNumeric'));
  }

  // Validation to the cg_url value
  if (!valid_url($form_state['values']['cg_url'], true)) {
    form_set_error('error', t('The URL to CG web-service value is not a valid url'));
  }

  // Validation to the cg_url value
  if (!preg_match('/^[A-Za-z]+$/', $form_state['values']['username'])) {
    form_set_error('error', t('The Username is not valid.'));
  }

  // Validation to the cg_url value
  if (!preg_match('/^[A-Za-z0-9@]+$/', $form_state['values']['password'])) {
    form_set_error('error', t('The Password is not valid.'));
  }

  // Validation to the cg_url value
  if (!valid_url($form_state['values']['ok_page'])) {
    form_set_error('error', t('The OK Page URL is not valid'));
  }

  // Validation to the cg_url value
  if (!valid_url($form_state['values']['not_ok_page'])) {
    form_set_error('error', t('The NOT OK Page URL is not valid'));
  }

  // Validation to the installments value
  if (!is_numeric($form_state['values']['installments'])) {
    form_set_error('error', t('The Installments value is not numeric'));
  }
  
}

/**
 * Form submission handler for cg_payment_admin_settings().
 *
 * @see cg_payment_admin_settings()
 */
function cg_payment_admin_settings_submit($form, &$form_state) {
  
  // Sets each of the form values as a variable with the cg_payment_admin_settings_ prefix
  foreach ($form_state['values'] as $key => $value) {
    variable_set('cg_payment_admin_settings_' . $key, $value);
  }
  
  // This marks that the settings has been configured and the redirect function can be called.
  variable_set('cg_payment_admin_settings_configured', true);
  
  // Displayes a message.
  drupal_set_message(t('The configuration options have been saved.'));
}