<?php

/**
 * Tests a payment request to credit guard
 */
function cg_payment_test_request($form, &$form_state) {

  $form['cardNo'] = array();
  $form['cardNo']['#type'] = 'value';
  $form['cardNo']['#value'] = 'CGMPI';
  $form['cardNo']['#required'] = true;

  $form['total'] = array();
  $form['total']['#type'] = 'textfield';
  $form['total']['#title'] = 'Total';
  $form['total']['#default_value'] = 10;
  $form['total']['#required'] = true;

  $form['currency'] = array();
  $form['currency']['#type'] = 'textfield';
  $form['currency']['#title'] = 'Currency';
  $form['currency']['#default_value'] = 'ILS';
  $form['currency']['#required'] = true;

  $form['transactionType'] = array();
  $form['transactionType']['#type'] = 'radios';
  $form['transactionType']['#options'] = array('Debit' => t('Debit'), 'Credit' => t('Credit'));
  $form['transactionType']['#default_value'] = 'Debit';
  $form['transactionType']['#title'] = 'transactionType';
  $form['transactionType']['#required'] = true;

  $form['transactionCode'] = array();
  $form['transactionCode']['#type'] = 'radios';
  $form['transactionCode']['#options'] = array('Phone' => t('Phone'), 'Magnetic' => t('Magnetic'));
  $form['transactionCode']['#default_value'] = 'Phone';
  $form['transactionCode']['#title'] = 'transactionCode';
  $form['transactionCode']['#required'] = true;

  $form['validation'] = array();
  $form['validation']['#type'] = 'value';
  $form['validation']['#value'] = 'TxnSetup';
  $form['validation']['#required'] = true;

  $form['uniqueid'] = array();
  $form['uniqueid']['#type'] = 'textfield';
  $form['uniqueid']['#default_value'] = 'test_' . variable_get('cg_payment_test_request_uniqueid', 1);
  $form['uniqueid']['#required'] = true;
  $form['uniqueid']['#title'] = t('Order Id');
  $form['uniqueid']['#description'] = t('The order id to pass to credit guard');

  $form['mpiValidation'] = array();
  $form['mpiValidation']['#type'] = 'select';
  $form['mpiValidation']['#options'] = array('Token' => t('Token'), 'Verify' => t('Verify'), 'AutoComm' => t('AutoComm'), 'AutoCommHold' => t('AutoCommHold'), 'CardNo' => t('CardNo'));
  $form['mpiValidation']['#default_value'] = 'AutoComm';
  $form['mpiValidation']['#title'] = 'mpiValidation';
  $form['mpiValidation']['#required'] = true;

  $form['creditType'] = array();
  $form['creditType']['#type'] = 'value';
  $form['creditType']['#value'] = 'RegularCredit';
  $form['creditType']['#required'] = true;

  $form['user'] = array();
  $form['user']['#type'] = 'textfield';
  $form['user']['#title'] = 'user';

  $form['numberOfPayments'] = array();
  $form['numberOfPayments']['#type'] = 'select';
  $form['numberOfPayments']['#options'] = array();
  for ($i=1; $i<=variable_get('cg_payment_admin_settings_installments', 1); $i++) {
    $form['numberOfPayments']['#options'][] = $i;
  }
  $form['numberOfPayments']['#title'] = 'number Of Payments';

  $form['firstPayment'] = array();
  $form['firstPayment']['#type'] = 'textfield';
  $form['firstPayment']['#title'] = 'firstPayment';

  $form['periodicalPayment'] = array();
  $form['periodicalPayment']['#type'] = 'textfield';
  $form['periodicalPayment']['#title'] = 'periodicalPayment';

  $form['eci'] = array();
  $form['eci']['#type'] = 'textfield';
  $form['eci']['#title'] = 'eci';

  $form['description'] = array();
  $form['description']['#type'] = 'textfield';
  $form['description']['#title'] = 'description';

  $form['email'] = array();
  $form['email']['#type'] = 'textfield';
  $form['email']['#title'] = 'email';
  
  $form['customerData'] = array();
  $form['customerData']['#title'] = 'Customer Data';
  $form['customerData']['#type'] = 'fieldset';
  
  for ($i=1; $i<=10; $i++) {
    $form['customerData']['userData' . $i] = array();
    $form['customerData']['userData' . $i]['#type'] = 'textfield';
    $form['customerData']['userData' . $i]['#title'] = 'userData1';
  }

  // The submit button
  $form['submit'] = array('#type' => 'submit', '#value' => t('Test'));

  // The validate function
  $form['#validate'][] = 'cg_payment_test_request_validate';
  
  // The submit function
  $form['#submit'][] = 'cg_payment_test_request_submit';
  
  return $form;
}

/**
 * Form validation handler for cg_payment_admin_settings().
 *
 * @see cg_payment_admin_settings()
 */
function cg_payment_test_request_validate($form, &$form_state) {

  // Validation to the Total value
  if (!is_numeric($form_state['values']['total']) && !is_float($form_state['values']['total'])) {
    form_set_error('error', t('The Total value is not numeric or float'));
  }
  else if (!preg_match('/^\d{1,8}$/', $form_state['values']['total'])) {
    form_set_error('error', t('The Total value has more than 8 characters'));
  }

  // Validation to the Currency value
  if (!preg_match('/^[A-Za-z0-9]{3}$/', $form_state['values']['currency'])) {
    form_set_error('error', t('The Currency value is not AlphaNumeric with three chars'));
  }

  // Validation to the transactionType value
  if (!preg_match('/^(Debit|Credit)$/i', $form_state['values']['transactionType'])) {
    form_set_error('error', t('The transactionType value is not Debit | Credit'));
  }

  // Validation to the transactionCode value
  if (!preg_match('/^(Phone|Magnetic)$/i', $form_state['values']['transactionCode'])) {
    form_set_error('error', t('The Currency transactionCode is not Phone | Magnetic'));
  }

  // Validation to the mpiValidation value
  if (!preg_match('/^(Token|Verify|AutoComm|AutoCommHold|CardNo)$/i', $form_state['values']['mpiValidation'])) {
    form_set_error('error', t('The Currency mpiValidation is not Token | Verify | AutoComm | AutoCommHold | CardNo'));
  }
  
}

/**
 * Form submission handler for cg_payment_admin_settings().
 *
 * @see cg_payment_admin_settings()
 */
function cg_payment_test_request_submit($form, &$form_state) {  
  $request = array();
  foreach ($form_state['values'] as $key => $value) {
    if (preg_match('/^(submit|form_build_id|form_token|form_id|op)$/', $key))
      continue;
    if (isset($form['customerData'][$key])) {
      $request['customerData'][$key] = $value;
    }
    else {
      $request[$key] = $value;
    }
  }
  
  variable_set('cg_payment_test_request_uniqueid', variable_get('cg_payment_test_request_uniqueid', 0)+1);
  cg_payment_redirect($request);
  
  drupal_set_message(t('The test is complete'));
}